#
# spec file for package ayatana-ido
#
# Copyright (c) 2021-2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libayatana-ido3-0_4-0
%define soname  libayatana-ido3-0.4
%define sover   0
%define typelib typelib-1_0-AyatanaIdo3-0_4
Name:           ayatana-ido
Version:        0.10.4
Release:        1.1
Summary:        Ayatana Indicator Display Objects
License:        GPL-3.0-only AND LGPL-3.0-only AND LGPL-2.1-only
Group:          System/GUI/Other
URL:            https://github.com/AyatanaIndicators/ayatana-ido
Source:         https://github.com/AyatanaIndicators/ayatana-ido/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.16
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(xorg-macros)

%description
Widgets and other objects used for indicators.

%package -n %{lname}
Summary:        Shared library providing extra GTK menu items in system indicators
Group:          System/Libraries

%description -n %{lname}
Shared library providing extra GTK menu items for display in
system indicators.

This package contains shared libraries.

%package -n %{typelib}
Summary:        Ayatana Indicator Display Objects typelib
Group:          System/Libraries

%description -n %{typelib}
Shared library providing extra GTK menu items for display in
system indicators.

This package provides the GObject Introspection bindings for
Ayatana Ido.

%package devel
Summary:        Development files for Ayatana Indicator Display Objects
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       %{typelib} = %{version}
Requires:       pkgconfig(gobject-introspection-1.0)

%description devel
Shared library providing extra GTK menu items for display in
system indicators.

This package contains the development files for Ido.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING*
%{_libdir}/%{soname}.so.%{sover}*

%files -n %{typelib}
%{_libdir}/girepository-1.0/AyatanaIdo3-0.4.typelib

%files devel
%license COPYING*
%doc AUTHORS* ChangeLog
%{_includedir}/%{soname}/
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/%{soname}.pc
%{_datadir}/gir-1.0/AyatanaIdo3-0.4.gir
%dir %{_datadir}/vala/vapi/
%{_datadir}/vala/vapi/libayatana-ido3-0.4.vapi

%changelog
* Wed Apr 30 2025 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
- Update to version 0.10.4:
  * src/idoscalemenuitem.c: Disable menu item selection
  * src/idoscalemenuitem.c: Add ability to close the menu when the
    slider's value changes.
- Update to version 0.10.3:
  * src/idoswitchmenuitem.c: Allow the switch to display an
    accelerator.
* Tue Apr  9 2024 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
- Update to version 0.10.2:
  * src/idoscalemenuitem.c: Make page increment same as step increment.
  * src/idoscalemenuitem.c: Add new functionality via the digits and
    marks parameters.
* Sat Nov 18 2023 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
- Update to version 0.10.1:
  * src/idoalarmmenuitem.c: Do not free non memory-allocated variable
  * Fix possible memory leaks.
  * Do not hardcode icon sizes.
  * cmake: Install library as library.
  * Update/add COPYING files, ship COPYING files for all licensed used.
- Update to version 0.10.0:
  * Add level menu item.
  * CMakeLists.txt: Add threads fix for old CMake.
  * src/idoprogressmenuitem.c: Rewrite to use icon, progress property and
    activation.
  * Revert "cmake: Enable building tests by default".
- Update to version 0.9.3:
  * cmake: Enable building tests by default.
  * tests: Fix building against modern GTest.
  * src/idobasicmenuitem.c: Set secondary text and count with lozenge from
    menu model.
* Fri Jun  3 2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
- Update to version 0.9.2:
  * src/CMakeLists.txt: link libm for expf, pow and sinf.
  * vala: The name of the vapi should match the pkg-config name.
- Drop ayatana-ido-0.9.0-libm.patch. Applied upstream.
- Adjust to .vapi file renaming by upstream (AyatanaIdo3-0.4.vapi ->
  libayatana-ido3-0.4.vapi.
* Wed Nov 24 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.9.0:
  * Switch to CMake from autotools.
  * Add better documentation.
  * data/libayatana-ido3-0.4.pc.in: Add glib-2.0 dependency.
  * src/idoappointmentmenuitem.c: Construct the basic menu item
    using the pixbuf property.
  * src/basicmenuitem.c: Add GdkPixbuf source support for the
    icon.
  * src/idoremovablemenuitem.c: Replace grid with box to fix
    a11y.
  * src/idolocationmenuitem.c: Fix deprecated g_time_zone_new
    warning.
  * Fix a unit test failure on Ubuntu 20.04.
  * Use consistent Ayatana IDO names. This version of Ayatana IDO
    breaks NG system indicators before 0.9.x.
- Drop pkgconfig-requires.patch: merged upstream.
- Add ayatana-ido-0.9.0-libm.patch: Link with libm to fix build.
- Restore Group.
* Thu Jun  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.8.2
  * Add a new menu item type: IDO Removable.
  * Add optional markup to the basic menu item.
  * Replace x-canonical attributes solely used by Ayatana Indicators
  * Drop IDO Message Dialog.
  * Centre playback menu item spinner/Pad application menu item label.
  * Centre volume control/Stretch calendar horizontally.
  * Updated colour getter for playback control.
- Drop upstream fixed
  * ayatana-ido-glib-2.58.patch
  * 0001-gtk_widget_get_state-is-deprecated.patch
- Add pkgconfig-requires.patch
  * Add all public dependencies to pkgconfig Requires section
* Wed Sep 16 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch to fix build:
  * 0001-gtk_widget_get_state-is-deprecated.patch
* Fri Nov  8 2019 Marguerite Su <i@marguerite.su>
- add ayatana-ido-glib-2.58.patch
  * g_type_class_add_private was deprecated since glib 2.58
    get rid of it and self-defined *_GET_PRIVATE() functions,
    use G_DEFINE_TYPE_* and auto-generated *_get_instance_private()
    instead.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sat Aug 18 2018 sor.alexei@meowr.ru
- Update to version 0.4.4 (changes since 0.4.2):
  * Fix the Name field in the libayatana-ido3.pc.in file.
* Mon Mar 12 2018 sor.alexei@meowr.ru
- Initial package.
